fix in summing over neutron beam time bins (.sum() to np.sum(..., axis=1))
Unit Testing / test (3.10) (pull_request) Successful in 1m10s
Unit Testing / test (3.12) (pull_request) Successful in 1m7s
Unit Testing / test (3.9) (pull_request) Successful in 1m6s
Unit Testing / test (3.11) (pull_request) Successful in 1m23s
Unit Testing / test (3.8) (pull_request) Successful in 1m24s

This commit is contained in:
stahn committed 2026-08-26 10:11:06 +02:00
1 parent be161bc2ba
commit d60e405152
1 file changed
+1 -1
+1 -1
View File
@@ -581,7 +581,7 @@ class AmorEventData(AmorHeader):
(_time<=packets.time[-1])]
beam_monitor = np.recarray(shape=np.shape(_time)[0], dtype=BM_TYPE)
beam_monitor.time = _time
beam_monitor.value[:] = _signal[:][plse].sum() - _signal[:][base].sum()
beam_monitor.value[:] = np.sum(_signal[:, plse], axis=1) - np.sum(_signal[:, base], axis=1)
return beam_monitor
def info(self):